#[task]Expand description
Preserve a synchronous function and generate function_task() beside it.
Task functions return a Result whose successful value implements Serialize.
#[task]Preserve a synchronous function and generate function_task() beside it.
Task functions return a Result whose successful value implements Serialize.